.. shopyo documentation master file, created by
   sphinx-quickstart on Sat Mar  7 23:26:49 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to Shopyo's docs!
=========================

Shopyo an Open web framework. It is HIGHLY MODULAR and is built for BIG projects.


The ecommerce part has been offloaded to
`ShopCube <https://github.com/shopyo/shopcube>`_


.. toctree::
   :maxdepth: 9

   Setting up Shopyo <setup>
   Education section <education>
   Contributing to Shopyo <contrib>
   Modules/Apps <modules>
   Assets <assets>
   Templates <templates>
   Models <models>
   Views <views>
   Commandline <commandline>
   Shopyoapi <shopyoapi>
   Docs <docs>
   Testing <testing>
   Deploy on shared hosting <shared_hosting>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
